package Log::ger::Screen::ColorSchemes::Kuler;

our $DATE = '2017-08-03'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Some popular color schemes from Adobe Kuler

__END__

=pod

=encoding UTF-8

=head1 NAME

Log::ger::Screen::ColorSchemes::Kuler - Some popular color schemes from Adobe Kuler

=head1 VERSION

version 0.003

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
